import React from 'react';

const DeveloperAmenitiesPriceStep = ({
  projectExpectedPrice,
  setProjectExpectedPrice,
  projectPriceUnit,
  setProjectPriceUnit,
  projectAmenities,
  setProjectAmenities,
  projectPlotDetails,
  setProjectPlotDetails
}) => {
  const amenities = [
    "GYM", 
    "Drainage", 
    "Children Park", 
    "Main Entrance Gate", 
    "Landscaping", 
    "Plantation", 
    "Internal Road", 
    "Boundary Wall", 
    "Security Service", 
    "Temple", 
    "Water", 
    "Electricity", 
    "Drainage system"
  ];

  const handleProjectAmenityToggle = (amenity) => {
    const key = amenity.toLowerCase().replace(/\s+/g, '');
    setProjectAmenities(prev => ({
      ...prev,
      [key]: !prev[key]
    }));
  };

  const handleProjectPlotDetailsChange = (field, value) => {
    setProjectPlotDetails(prev => ({
      ...prev,
      [field]: value
    }));
  };

  return (
    <div className="space-y-6 w-full p-4">
      {/* Amenities Section */}
      <div>
        <h3 className="text-lg font-medium mb-4">Project Amenities</h3>
        <div className="grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-5 gap-4">
          {amenities.map((amenity) => {
            const key = amenity.toLowerCase().replace(/\s+/g, '');
            return (
              <label 
                key={key} 
                className="flex items-center space-x-2 cursor-pointer"
              >
                <input
                  type="checkbox"
                  checked={projectAmenities[key]}
                  onChange={() => handleProjectAmenityToggle(amenity)}
                  className="h-4 w-4 text-purple-600 focus:ring-purple-500 border-gray-300 rounded"
                />
                <span className="text-sm">
                  {amenity}
                </span>
              </label>
            );
          })}
        </div>
      </div>

      {/* Pricing Section */}
      <div className="space-y-4">
        <h3 className="text-lg font-medium">Project Pricing Details</h3>
        <div className="grid md:grid-cols-2 gap-4">
          <div>
            <label htmlFor="projectExpectedPrice" className="block text-sm font-medium mb-2">
              Expected Project Price
            </label>
            <div className="flex">
              <input
                id="projectExpectedPrice"
                type="text"
                value={projectExpectedPrice}
                onChange={(e) => setProjectExpectedPrice(e.target.value)}
                placeholder="Enter Project Price"
                className="w-full rounded-l-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none"
              />
              <select
                value={projectPriceUnit}
                onChange={(e) => setProjectPriceUnit(e.target.value)}
                className="rounded-r-lg border border-l-0 border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none"
              >
                <option value="Total">Total</option>
                <option value="p/sq Feet">p/sq Feet</option>
                <option value="p/sq Yards">p/sq Yards</option>
              </select>
            </div>
          </div>
        </div>
      </div>

      {/* Plot Details Section */}
      <div className="space-y-4">
        <h3 className="text-lg font-medium">Project Plot Information</h3>
        <div className="grid md:grid-cols-2 gap-4">
          <div>
            <label htmlFor="projectPlotNumber" className="block text-sm font-medium mb-2">
              Project Plot Number
            </label>
            <input
              id="projectPlotNumber"
              type="text"
              value={projectPlotDetails.plotNumber}
              onChange={(e) => handleProjectPlotDetailsChange('plotNumber', e.target.value)}
              placeholder="Enter Project Plot Number"
              className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none"
            />
          </div>
          <div>
            <label htmlFor="projectPlotSize" className="block text-sm font-medium mb-2">
              Project Plot Size
            </label>
            <div className="flex">
              <input
                id="projectPlotSize"
                type="text"
                value={projectPlotDetails.plotSize}
                onChange={(e) => handleProjectPlotDetailsChange('plotSize', e.target.value)}
                placeholder="Enter Project Plot Size"
                className="w-full rounded-l-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none"
              />
              <select
                value={projectPlotDetails.plotSizeUnit}
                onChange={(e) => handleProjectPlotDetailsChange('plotSizeUnit', e.target.value)}
                className="rounded-r-lg border border-l-0 border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none"
              >
                <option value="">Select Unit</option>
                <option value="sqFeet">sq Feet</option>
                <option value="sqYards">sq Yards</option>
                <option value="sqMeters">sq Meters</option>
              </select>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default DeveloperAmenitiesPriceStep;